==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/admin_info_boxes.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_info_boxes.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BUTTON_CLEAR_CACHE' => 'Seitencache leeren',
	'BUTTON_SHOW_LOG' => 'Log anzeigen',
	'CLOSE' => 'ausblenden',
	'DELETE' => 'löschen',
	'ERROR_SESSION_EXPIRED' => 'Der Cache wurde NICHT gelöscht! Bitte loggen Sie sich neu ein.',
	'guest_accounts_deleted_heading' => 'Gast-Konten gelöscht',
	'guest_accounts_deleted_message' => 'Es wurden alle Gast-Konten, die aktuell nicht in Benutzung sind, erfolgreich gelöscht.',
	'HEADLINE_CLEAR_CACHE' => 'Seitencache leeren',
	'HEADLINE_NEW_LOG_ENTRIES' => 'Neue Log-Einträge',
	'IN_PROGRESS' => 'in Bearbeitung...',
	'NOT_LOGGED_ID' => 'Der Cache wurde NICHT gelöscht! Bitte loggen Sie sich neu ein.',
	'NO_MESSAGES' => 'Es sind keine aktuellen Nachrichten vorhanden.',
	'shop_key_valid_heading' => 'Shop-Key gültig',
	'shop_key_valid_message' => 'Ihr Gambio Shop-Key ist gültig.',
	'SHOW_ALL' => 'Alle anzeigen',
	'TEXT_CLEAR_CACHE' => 'Sie haben Änderungen vorgenommen, die möglicherweise die Seitenausgabe im Shop betreffen.<br />Leeren Sie den Seitenausgabe-Cache, um die Änderungen im Shop sichtbar zu machen.',
	'TEXT_NEW_LOG_ENTRIES' => 'Es gibt neue Einträge im <a href="show_logs.php?file=%s"><u>%s</u></a>.',
    'LOADING' => 'Nachrichten werden geladen...'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/admin_info_boxes.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_info_boxes.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BUTTON_CLEAR_CACHE' => 'Seitencache leeren',
	'BUTTON_SHOW_LOG' => 'Log anzeigen',
	'CLOSE' => 'ausblenden',
	'DELETE' => 'löschen',
	'ERROR_SESSION_EXPIRED' => 'Der Cache wurde NICHT gelöscht! Bitte logge dich neu ein.',
	'guest_accounts_deleted_heading' => 'Gast-Konten gelöscht',
	'guest_accounts_deleted_message' => 'Es wurden alle Gast-Konten, die aktuell nicht in Benutzung sind, erfolgreich gelöscht.',
	'HEADLINE_CLEAR_CACHE' => 'Seitencache leeren',
	'HEADLINE_NEW_LOG_ENTRIES' => 'Neue Log-Einträge',
	'IN_PROGRESS' => 'in Bearbeitung...',
	'NOT_LOGGED_ID' => 'Der Cache wurde NICHT gelöscht! Bitte logge dich neu ein.',
	'NO_MESSAGES' => 'Es sind keine aktuellen Nachrichten vorhanden.',
	'shop_key_valid_heading' => 'Shop-Key gültig',
	'shop_key_valid_message' => 'Dein Gambio Shop-Key ist gültig.',
	'SHOW_ALL' => 'Alle anzeigen',
	'TEXT_CLEAR_CACHE' => 'Du hast Änderungen vorgenommen, die möglicherweise die Seitenausgabe im Shop betreffen.<br />Leere den Seitenausgabe-Cache, um die Änderungen im Shop sichtbar zu machen.',
	'TEXT_NEW_LOG_ENTRIES' => 'Es gibt neue Einträge im <a href="show_logs.php?file=%s"><u>%s</u></a>.',
    'LOADING' => 'Nachrichten werden geladen...'
);
